%define	major		2.5
%define	libname		%mklibname openimageio %{major}
%define	develname	%mklibname openimageio -d

#OSL 1.11 doesn't work with fmt9
%bcond_without  fmt8
%define		fmtver	8.1.1

# The build scripts of openimageio downloads some test images at
# building time using git.
#
# To avoid this set -DOIIO_DOWNLOAD_MISSING_TESTDATA:BOOL in
# cmake configuration. Also there is the possibility to use a
# downloaded test images offline by setting the flag below
# 'with_offline_test_images', as follows:
#
# 1 -> use a previously downloaded offline test image archive.
# 0 -> don't use an offline test image archive
#
# (use the script in Source2 to generate the offline image tarball).
#
%define		with_offline_test_images	0

Name:		openimageio
Version:	2.5.14.0
Release:	%mkrel 1
Summary:	Library for reading and writing images
Group:		System/Libraries
License:	BSD
URL:		https://sites.google.com/site/openimageio/home
Source0:	https://github.com/AcademySoftwareFoundation/OpenImageIO/archive/v%{version}/OpenImageIO-%{version}.tar.gz
# script to build offline
Source1:	gen-test-images-archive.sh
%if %{with_offline_test_images}
Source2:	openimageio-%{version}-test-images.tar.gz
%endif
Source3:	https://github.com/fmtlib/fmt/archive/%{fmtver}/fmt-%{fmtver}.tar.gz
#
# from upstream
Patch10:	0001-build_Make-C++17-be-the-default.patch
#
#
# Mageia patches
#
Patch101:	0001-Allow-building-without-ARM-NEON-support.patch

BuildRequires:	boost-devel
BuildRequires:	clang-tools-extra
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	cmake(DCMTK)
BuildRequires:	cmake(tsl-robin-map)
BuildRequires:	field3d-devel
BuildRequires:	giflib-devel
BuildRequires:	git-core
BuildRequires:	hdf5-devel
%ifarch aarch64 x86_64
BuildRequires:	openvdb-devel
%endif
%if ! %{with fmt8}
BuildRequires:	pkgconfig(fmt) <= %{fmtver}
%endif
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(jasper)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(libraw_r)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libwebp)
BuildRequires:	pkgconfig(OpenColorIO)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(Ptex)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pybind11-devel
BuildRequires:	squish-devel
BuildRequires:	txt2man

BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6OpenGL)
BuildRequires:	cmake(Qt6OpenGLWidgets)
BuildRequires:	cmake(Qt6Widgets)

%description
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. Main features include:
- Extremely simple but powerful ImageInput and ImageOutput APIs for reading and
  writing 2D images that is format agnostic.
- Format plugins for TIFF, JPEG/JFIF, OpenEXR, PNG, HDR/RGBE, Targa, JPEG-2000,
  DPX, Cineon, FITS, BMP, ICO, RMan Zfile, Softimage PIC, DDS, SGI,
  PNM/PPM/PGM/PBM, Field3d.
- An ImageCache class that transparently manages a cache so that it can access
  truly vast amounts of image data.
- A really nice image viewer, iv, also based on OpenImageIO classes (and so
  will work with any formats for which plugins are available).

%package -n %{libname}
Summary:	A library for reading and writing images
Group:		System/Libraries

%description -n %{libname}
OpenImageIO is a library for reading and writing images.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
%if %{with fmt8}
Provides:	bundled(fmt) = %{fmtver}
%endif

%description -n %{develname}
Development files for %{name} library.

%package -n python3-%{name}
Summary:	Python 3 bindings for %{name}
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python3-OpenImageIO = %{version}-%{release}

%description -n python3-%{name}
Python3 bindings for %{name}.

%prep
%if %{with_offline_test_images}
%autosetup -a 2 -n OpenImageIO-%{version} -Sgit_am
%else
%autosetup -n OpenImageIO-%{version} -Sgit_am
%endif

# Remove bundled pugixml
rm -f src/include/OpenImageIO/pugixml.hpp \
      src/include/OpenImageIO/pugiconfig.hpp \
      src/include/OpenImageIO/pugixml.cpp

# Remove bundled tbb
rm -rf src/include/tbb

%if %{with fmt8}
tar xf %{SOURCE3} -C ./
mkdir -p ext
mv fmt-%{fmtver} ext/fmt
%endif

# install ttf fonts in /usr/share/fonts/TTF
sed -i 's|/fonts/OpenImageIO|/fonts/TTF/OpenImageIO|' src/fonts/CMakeLists.txt

%build
# this defines the path where openimageio looks up for
# plugins: -DPLUGIN_SEARCH_PATH=%%{_libdir}/OpenImageIO%%{major}
%cmake -GNinja \
       -DPYTHON_VERSION=%{python3_version} \
       -DUSE_PYTHON:BOOL=ON \
       -DSTOP_ON_WARNING:BOOL=OFF \
       -DUSE_EXTERNAL_PUGIXML:BOOL=ON \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DVERBOSE:BOOL=ON \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
       -DCMAKE_SKIP_RPATH:BOOL=ON \
       -DOIIO_DOWNLOAD_MISSING_TESTDATA:BOOL=OFF \
%if %{with_offline_test_images}
       -DOIIO_LOCAL_TESTDATA_ROOT=testsuite \
%endif
%ifarch %{arm32}
       -DOIIO_NO_NEON:BOOL=ON \
%endif
%if %{with fmt8}
       -DFMT_VERSION:STRING=%(tr '.' '0' <<< %{fmtver}) \
%endif
       %nil
%cmake_build

%install
%cmake_install

# Move man pages to the right directory
mkdir -p %{buildroot}%{_mandir}/man1
mv %{buildroot}%{_mandir}/*.1 %{buildroot}%{_mandir}/man1

rm -fr %{buildroot}%{_docdir}

%files
%license LICENSE.md
%{_bindir}/*
%{_xfontdir}/TTF/OpenImageIO
%{_mandir}/man1/*

%files -n %{libname}
%license LICENSE.md
%{_libdir}/libOpenImageIO.so.%{major}{,.*}
%{_libdir}/libOpenImageIO_Util.so.%{major}{,.*}

%files -n %{develname}
%doc CHANGES.md
%doc README.md
%license LICENSE.md
%{_libdir}/libOpenImageIO.so
%{_libdir}/libOpenImageIO_Util.so
%dir %{_includedir}/OpenImageIO
%{_includedir}/OpenImageIO/*
%{_libdir}/pkgconfig/OpenImageIO.pc
%{_libdir}/cmake/OpenImageIO/

%files -n python3-%{name}
%{python3_sitearch}/OpenImageIO/


%changelog
* Sat Aug 03 2024 daviddavid <daviddavid> 2.5.14.0-1.mga10
+ Revision: 2083476
- new version: 2.5.14.0

* Tue Jul 02 2024 daviddavid <daviddavid> 2.5.13.0-1.mga10
+ Revision: 2079008
- new version: 2.5.13.0

* Wed Jun 19 2024 wally <wally> 2.5.11.0-2.mga10
+ Revision: 2075375
- rebuild for boost 1.85.0

* Thu May 02 2024 daviddavid <daviddavid> 2.5.11.0-1.mga10
+ Revision: 2061846
- new version: 2.5.11.0
- new version: 2.5.10.1

* Mon Mar 04 2024 daviddavid <daviddavid> 2.5.9.0-1.mga10
+ Revision: 2047456
- new version: 2.5.9.0

* Mon Jan 29 2024 daviddavid <daviddavid> 2.5.6.0-2.mga10
+ Revision: 2035734
- rebuild for tbb 2021.11.0

* Thu Jan 18 2024 daviddavid <daviddavid> 2.5.6.0-1.mga10
+ Revision: 2031920
- new version: 2.5.6.0

* Sun Jan 14 2024 daviddavid <daviddavid> 2.4.17.0-5.mga10
+ Revision: 2031204
- rebuild for new openvdb 11.0.0

* Sun Jan 14 2024 daviddavid <daviddavid> 2.4.17.0-4.mga10
+ Revision: 2031110
- install ttf fonts in '/usr/share/fonts/TTF'

* Fri Jan 12 2024 wally <wally> 2.4.17.0-3.mga10
+ Revision: 2030575
- rebuild for boost 1.84.0

* Mon Dec 25 2023 daviddavid <daviddavid> 2.4.17.0-2.mga10
+ Revision: 2021185
- rebuild for py3.12

* Thu Nov 02 2023 daviddavid <daviddavid> 2.4.17.0-1.mga10
+ Revision: 2003487
- new version: 2.4.17.0

* Mon Oct 30 2023 daviddavid <daviddavid> 2.4.16.0-1.mga10
+ Revision: 2002849
- new version: 2.4.16.0

* Mon Oct 30 2023 daviddavid <daviddavid> 2.4.15.0-5.mga10
+ Revision: 2002822
- backport upstream patch to make C++17 be the default
- rebuild for new openvdb 10.1.0

* Wed Oct 25 2023 daviddavid <daviddavid> 2.4.15.0-4.mga10
+ Revision: 2001689
- switch to Qt6

* Wed Oct 25 2023 daviddavid <daviddavid> 2.4.15.0-3.mga10
+ Revision: 2001573
- rebuild for new opencolorio 2.3.0

* Wed Sep 27 2023 wally <wally> 2.4.15.0-2.mga10
+ Revision: 1991478
- rebuild for boost 1.83.0

* Sat Sep 02 2023 daviddavid <daviddavid> 2.4.15.0-1.mga10
+ Revision: 1983512
- new version: 2.4.15.0

* Tue Apr 11 2023 ns80 <ns80> 2.4.10.0-1.mga9
+ Revision: 1952601
- version 2.4.10.0 for many CVEs (mga#31364)

* Sun Jan 01 2023 wally <wally> 2.4.6.1-6.mga9
+ Revision: 1928623
- add patch to support building without ARM NEON support
  (not sure if this is really needed, but add it anyway)

* Sun Jan 01 2023 wally <wally> 2.4.6.1-5.mga9
+ Revision: 1928546
- rebuild for armv7 (typo fix)

* Sun Jan 01 2023 wally <wally> 2.4.6.1-4.mga9
+ Revision: 1928537
- properly build without NEON on armv7

* Sun Jan 01 2023 wally <wally> 2.4.6.1-3.mga9
+ Revision: 1928524
- build without NEON support on armv7

* Sun Jan 01 2023 wally <wally> 2.4.6.1-2.mga9
+ Revision: 1928506
- restore use of bundled fmt 8.1.1 for OSL 1.11

* Sat Dec 31 2022 wally <wally> 2.4.6.1-1.mga9
+ Revision: 1928459
- new version 2.4.6.1
- new lib major 2.4

* Tue Dec 27 2022 daviddavid <daviddavid> 2.3.21.0-6.mga9
+ Revision: 1927148
- rebuild for new openvdb 10.0.1

* Sat Dec 24 2022 wally <wally> 2.3.21.0-5.mga9
+ Revision: 1926511
- rebuild for boost 1.81.0

* Thu Dec 15 2022 ghibo <ghibo> 2.3.21.0-4.mga9
+ Revision: 1923220
- Rebuild against final libtiff-4.5.0.
- Remove patch to build against libtiff-4.5.0-rc1, as no longer needed

* Tue Dec 13 2022 ghibo <ghibo> 2.3.21.0-3.mga9
+ Revision: 1921641
- Add missed clang-tools-extra (for clang-format) to BR
+ ns80 <ns80>
- add a patch to fix building with libtiff 4.5
- rebuild for new libtiff

* Sat Nov 05 2022 ghibo <ghibo> 2.3.21.0-2.mga9
+ Revision: 1903823
- Versioning fmt
- Rebuild against fmt8 to avoid breakage with fmt9

* Wed Nov 02 2022 ghibo <ghibo> 2.3.21.0-1.mga9
+ Revision: 1901509
- Update to release 2.3.21.0.
- Remove patches merged upstream.

* Wed Nov 02 2022 ghibo <ghibo> 2.3.20.0-4.mga9
+ Revision: 1901479
- Rebuild for newer opencv

* Tue Nov 01 2022 ghibo <ghibo> 2.3.20.0-3.mga9
+ Revision: 1900944
- Rebuild against opencv 4.6.0

* Mon Oct 31 2022 ghibo <ghibo> 2.3.20.0-2.mga9
+ Revision: 1900681
- Merge patches from upstream

* Wed Oct 12 2022 ghibo <ghibo> 2.3.20.0-1.mga9
+ Revision: 1896516
- Update to release 2.3.20.0
+ papoteur <papoteur>
- Simplify file list, no risk of directory not owned

* Fri Sep 30 2022 papoteur <papoteur> 2.3.19.0-1.mga9
+ Revision: 1893509
- new 2.3.19.0
- new 2.3.19.0

* Mon Sep 19 2022 papoteur <papoteur> 2.3.13.0-3.mga9
+ Revision: 1890330
- Rebuild for dcmtk

* Sun Jul 03 2022 wally <wally> 2.3.13.0-2.mga9
+ Revision: 1867291
- rebuild for boost 1.79.0

* Thu Mar 31 2022 kekepower <kekepower> 2.3.13.0-1.mga9
+ Revision: 1837026
- Update to version 2.3.13.0 to build with ffmpeg 5.0
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Thu Feb 17 2022 akien <akien> 2.3.12.0-1.mga9
+ Revision: 1779170
- Version 2.3.12.0
+ ghibo <ghibo>
- Add conditional building flag for using the test image archive offline.
- Prepare support for Ptex in BuildRequires.
- Add CMAKE_SKIP_RPATH beside CMAKE_SKIP_INSTALL_RPATH as it seems to still setting some RPATH from cmake logs.
- Enforce USE_EXTERNAL_PUGIXML to ON (more robust).
- Set OIIO_DOWNLOAD_MISSING_TESTDATA to OFF to avoid contacting remote servers during building for downloading test images.
- Add comment about PLUGIN_SEARCH_PATH.

* Sun Dec 26 2021 wally <wally> 2.3.10.1-1.mga9
+ Revision: 1764099
- new version 2.3.10.1
- new lib major 2.3
- rebuild for openexr 3.1.3

* Sun Dec 19 2021 wally <wally> 2.2.15.1-4.mga9
+ Revision: 1762687
- rebuild for boost 1.78.0

* Fri Sep 10 2021 wally <wally> 2.2.15.1-3.mga9
+ Revision: 1745106
- fix RPATH
- rebuild for boost 1.77.0

* Sat Jul 31 2021 wally <wally> 2.2.15.1-2.mga9
+ Revision: 1738281
- rebuild for opencolorio 2.0.1

* Fri Jun 04 2021 daviddavid <daviddavid> 2.2.15.1-1.mga9
+ Revision: 1729594
- new version: 2.2.15.1

* Fri May 14 2021 wally <wally> 2.2.14.0-2.mga9
+ Revision: 1722998
- rebuild for boost 1.76.0
- add patch to fix Field3D plugin linking

* Sun May 02 2021 daviddavid <daviddavid> 2.2.14.0-1.mga9
+ Revision: 1720853
- new version: 2.2.14.0

* Mon Apr 26 2021 daviddavid <daviddavid> 2.2.13.1-2.mga9
+ Revision: 1719823
- rebuild for new dcmtk 3.6.6

* Thu Apr 08 2021 daviddavid <daviddavid> 2.2.13.1-1.mga9
+ Revision: 1714080
- new version: 2.2.13.1

* Fri Apr 02 2021 daviddavid <daviddavid> 2.2.13.0-1.mga9
+ Revision: 1712594
- new version: 2.2.13.0

* Thu Mar 18 2021 daviddavid <daviddavid> 2.2.12.0-3.mga9
+ Revision: 1704213
- rebuild for python 3.9

* Sun Mar 07 2021 daviddavid <daviddavid> 2.2.12.0-2.mga9
+ Revision: 1700369
- rebuild for new openvdb 8.0.1

* Tue Mar 02 2021 daviddavid <daviddavid> 2.2.12.0-1.mga9
+ Revision: 1695726
- new version: 2.2.12.0

* Sat Feb 27 2021 daviddavid <daviddavid> 2.2.11.1-1.mga9
+ Revision: 1692551
- new version: 2.2.11.1

* Mon Jan 04 2021 daviddavid <daviddavid> 2.2.10.0-1.mga8
+ Revision: 1668585
- new version: 2.2.10.0

* Thu Dec 31 2020 wally <wally> 2.2.9.0-5.mga8
+ Revision: 1666794
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 2.2.9.0-4.mga8
+ Revision: 1662036
- rebuild for boost 1.74.0

* Thu Dec 17 2020 luigiwalser <luigiwalser> 2.2.9.0-3.mga8
+ Revision: 1660527
- rebuild for missing signature

* Thu Dec 17 2020 umeabot <umeabot> 2.2.9.0-2.mga8
+ Revision: 1659213
- Rebuild for new Qt5

* Fri Dec 04 2020 daviddavid <daviddavid> 2.2.9.0-1.mga8
+ Revision: 1652436
- new version: 2.2.9.0

* Tue Nov 03 2020 akien <akien> 2.2.8.0-1.mga8
+ Revision: 1642035
- Version 2.2.8.0
- Rebuild against opencv 4.5
+ daviddavid <daviddavid>
- new version: 2.2.7.0 (mga#27490)
- now libmajor is 2.2

* Sat Sep 12 2020 daviddavid <daviddavid> 2.1.19.0-2.mga8
+ Revision: 1625009
- rebuild for new openexr 2.5.3 and new hdf5 1.10.6

* Wed Sep 02 2020 daviddavid <daviddavid> 2.1.19.0-1.mga8
+ Revision: 1620758
- new version: 2.1.19.0

* Tue Aug 18 2020 daviddavid <daviddavid> 2.1.18.1-2.mga8
+ Revision: 1614926
- rebuild for new openvdb 7.1.0

* Sun Aug 02 2020 daviddavid <daviddavid> 2.1.18.1-1.mga8
+ Revision: 1610480
- new version: 2.1.18.1

* Sat Aug 01 2020 daviddavid <daviddavid> 2.1.18.0-1.mga8
+ Revision: 1610200
- new version: 2.1.18.0

* Thu Jul 02 2020 daviddavid <daviddavid> 2.1.17.0-1.mga8
+ Revision: 1601390
- new version: 2.1.17.0
- remove merged upstream patch

* Sat Jun 20 2020 daviddavid <daviddavid> 2.1.16.0-2.mga8
+ Revision: 1597542
- add upstream patch to fix Qt 5.15 support

* Tue Jun 02 2020 daviddavid <daviddavid> 2.1.16.0-1.mga8
+ Revision: 1589620
- new version: 2.1.16.0

* Mon May 11 2020 daviddavid <daviddavid> 2.1.15.0-1.mga8
+ Revision: 1583216
- new version: 2.1.15.0

* Sun May 03 2020 wally <wally> 2.1.14.0-2.mga8
+ Revision: 1578090
- rebuild for boost 1.73.0

* Sat May 02 2020 daviddavid <daviddavid> 2.1.14.0-1.mga8
+ Revision: 1577773
- new version: 2.1.14.0
- remove merged upstream patch

* Sat Apr 04 2020 daviddavid <daviddavid> 2.1.13.0-2.mga8
+ Revision: 1564544
- rebuild for new fmt 6.1.2

* Fri Apr 03 2020 daviddavid <daviddavid> 2.1.13.0-1.mga8
+ Revision: 1564135
- new version: 2.1.13.0
- now libmajor is 2.1
- enable field3d and squish support
- enable libheif and fmt support
- enable openvdb support

* Wed Feb 19 2020 umeabot <umeabot> 2.0.13-3.mga8
+ Revision: 1544853
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 2.0.13-2.mga8
+ Revision: 1483408
- rebuild for boost 1.72.0
- build with new cmake macros

* Wed Dec 04 2019 daviddavid <daviddavid> 2.0.13-1.mga8
+ Revision: 1464195
- new version: 2.0.13

* Tue Nov 05 2019 daviddavid <daviddavid> 2.0.12-1.mga8
+ Revision: 1457783
- new version: 2.0.12

* Thu Oct 31 2019 daviddavid <daviddavid> 2.0.11-3.mga8
+ Revision: 1457113
- rebuild for new dcmtk 3.6.5

* Mon Oct 07 2019 tv <tv> 2.0.11-2.mga8
+ Revision: 1450212
- rebuild with python 3.8

* Wed Oct 02 2019 daviddavid <daviddavid> 2.0.11-1.mga8
+ Revision: 1448720
- new version: 2.0.11

* Tue Sep 17 2019 daviddavid <daviddavid> 2.0.9-2.mga8
+ Revision: 1442778
- rebuild for python3.8

* Mon Jul 15 2019 daviddavid <daviddavid> 2.0.9-1.mga8
+ Revision: 1421558
- new version: 2.0.9
- now libmajor is 2.0
- switch to Python3 and drop Python2 support

* Sun Mar 31 2019 umeabot <umeabot> 1.8.17-3.mga7
+ Revision: 1383624
- Qt5 Rebuild

* Sun Jan 06 2019 daviddavid <daviddavid> 1.8.17-2.mga7
+ Revision: 1350093
- rebuild for new dcmtk 3.6.4

* Sun Dec 02 2018 daviddavid <daviddavid> 1.8.17-1.mga7
+ Revision: 1337383
- new version: 1.8.17

* Fri Nov 02 2018 daviddavid <daviddavid> 1.8.16-1.mga7
+ Revision: 1327565
- new version: 1.8.16

* Tue Oct 16 2018 wally <wally> 1.8.15-3.mga7
+ Revision: 1321071
- rebuild for new boost 1.68.0

* Mon Oct 15 2018 daviddavid <daviddavid> 1.8.15-2.mga7
+ Revision: 1320480
- rebuild for new ilmbase and openexr 2.3.0

* Tue Oct 02 2018 daviddavid <daviddavid> 1.8.15-1.mga7
+ Revision: 1315827
- new version: 1.8.15

* Mon Sep 03 2018 daviddavid <daviddavid> 1.8.14-1.mga7
+ Revision: 1256742
- new version: 1.8.14
- remove merged upstream patch

* Sun May 27 2018 wally <wally> 1.8.10-3.mga7
+ Revision: 1232427
- rebuild for openexr 2.2.1

* Tue May 01 2018 daviddavid <daviddavid> 1.8.10-2.mga7
+ Revision: 1224138
- enable DCMTK support

* Tue May 01 2018 daviddavid <daviddavid> 1.8.10-1.mga7
+ Revision: 1224102
- new version: 1.8.10
- switch to openjpeg2
- rename and rediff dl patch

* Tue May 01 2018 daviddavid <daviddavid> 1.8.6-5.mga7
+ Revision: 1224093
- add upstream patch to fix build with ffmpeg 4.0
- rename python-openimageio to python2-openimageio
- split out all Qt5 BRs

* Sat Jan 13 2018 wally <wally> 1.8.6-4.mga7
+ Revision: 1192567
- rebuild for new ilmbase

* Mon Dec 25 2017 wally <wally> 1.8.6-3.mga7
+ Revision: 1184694
- rebuild for new boost

* Sun Dec 03 2017 daviddavid <daviddavid> 1.8.6-2.mga7
+ Revision: 1180819
- rebuild for new glew 2.1.0

* Wed Nov 22 2017 tv <tv> 1.8.6-1.mga7
+ Revision: 1178682
- new major
- rediff patch 0
- remove no more needed patch 1
- fix man pages path
- fix filelist
- py3 build seems failing
- new release

* Tue Nov 21 2017 tv <tv> 1.7.17-1.mga7
+ Revision: 1178460
- new release
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1.7.14-3.mga7
+ Revision: 1154575
- rebuild with latest boost

* Sat Aug 05 2017 pterjan <pterjan> 1.7.14-2.mga7
+ Revision: 1135282
- Rebuild for python 3.6

* Tue May 16 2017 luigiwalser <luigiwalser> 1.7.14-1.mga6
+ Revision: 1102070
- 1.7.14
- add patch from fedora to fix arch/optimizer specific problem with
  uninitialized variables

* Tue May 02 2017 akien <akien> 1.7.9-3.mga6
+ Revision: 1098369
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 1.7.9-2.mga6
+ Revision: 1090229
- Rebuild for ffmpeg 3.2.4

* Wed Dec 28 2016 wally <wally> 1.7.9-1.mga6
+ Revision: 1078446
- new version 1.7.9
- fix pkg names (use lower case)
- rediff linking patch

* Tue Dec 27 2016 neoclust <neoclust> 1.6.17-2.mga6
+ Revision: 1078383
- Rebuild against new libraw

* Sat Oct 01 2016 daviddavid <daviddavid> 1.6.17-1.mga6
+ Revision: 1057976
- new version: 1.6.17

* Sat Apr 09 2016 daviddavid <daviddavid> 1.6.12-1.mga6
+ Revision: 999805
- new version: 1.6.12

* Sun Jan 10 2016 daviddavid <daviddavid> 1.6.9-2.mga6
+ Revision: 920961
- rebuild for new giflib 5.1.2

* Wed Jan 06 2016 daviddavid <daviddavid> 1.6.9-1.mga6
+ Revision: 920121
- new version: 1.6.9
- now libmajor is 1.6
- update file list

* Tue Jan 05 2016 daviddavid <daviddavid> 1.5.23-1.mga6
+ Revision: 919818
- new version: 1.5.23
- reenable python binding build (upstream fixed build with boost 1.60.0)
- move python bindings to their own subpackage
- add python 3 subpackage

* Sat Jan 02 2016 luigiwalser <luigiwalser> 1.5.22-2.mga6
+ Revision: 918204
- rebuild for libwebp

* Sun Dec 27 2015 daviddavid <daviddavid> 1.5.22-1.mga6
+ Revision: 916060
- new version: 1.5.22
- rebuild for new libraw 0.17.1

* Sat Dec 26 2015 daviddavid <daviddavid> 1.5.18-3.mga6
+ Revision: 915100
- temporarily disable python binding build (uncompatible with boost 1.60.0 for now)
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 1.5.18-2.mga6
+ Revision: 883479
- rebuild for new boost 1.59.0

* Wed Aug 26 2015 fwang <fwang> 1.5.18-1.mga6
+ Revision: 869481
- install man pages
- br opencolorio
- disable doc install
- update file list
- use openssl
- add more br
- 1.5.18

* Mon Aug 24 2015 daviddavid <daviddavid> 1.2.0-15.mga6
+ Revision: 868898
- rebuild for new glew 1.13.0

* Fri Jul 31 2015 fwang <fwang> 1.2.0-14.mga6
+ Revision: 859426
- rebuild for new boost

* Tue Jun 23 2015 fwang <fwang> 1.2.0-13.mga6
+ Revision: 840506
- rebuild for new glew

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0-12.mga5
+ Revision: 750496
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0-11.mga5
+ Revision: 683214
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 luigiwalser <luigiwalser> 1.2.0-10.mga5
+ Revision: 672251
- rebuild for glew

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.2.0-9.mga5
+ Revision: 666999
- rebuild for ilmbase and OpenEXR

* Thu Aug 07 2014 fwang <fwang> 1.2.0-8.mga5
+ Revision: 660835
- rebuild for new pugixml

* Fri Apr 25 2014 akien <akien> 1.2.0-7.mga5
+ Revision: 618074
- Rebuild for new OpenEXR and IlmBase

* Sat Feb 15 2014 luigiwalser <luigiwalser> 1.2.0-6.mga5
+ Revision: 592108
- rebuild for libwebp

* Sat Feb 08 2014 barjac <barjac> 1.2.0-5.mga5
+ Revision: 586737
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 1.2.0-4.mga4
+ Revision: 534418
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 fwang <fwang> 1.2.0-3.mga4
+ Revision: 477848
- rebuild for new openexr

* Wed Jul 24 2013 sander85 <sander85> 1.2.0-2.mga4
+ Revision: 457678
- Rebuild for new glew

* Mon Jul 15 2013 fwang <fwang> 1.2.0-1.mga4
+ Revision: 454647
- disable werror
- update dl patch
- new version 1.2.0

* Mon Jul 08 2013 fwang <fwang> 1.0.8-11.mga4
+ Revision: 451208
- rebuild for new boost

* Thu Jun 06 2013 fwang <fwang> 1.0.8-10.mga4
+ Revision: 438301
- rebuild again for updated openjpeg

* Thu Jun 06 2013 fwang <fwang> 1.0.8-9.mga4
+ Revision: 438284
- rebuild for new openjpeg

* Sun Jun 02 2013 fwang <fwang> 1.0.8-8.mga4
+ Revision: 434729
- rebuild for new libpng

* Thu Apr 11 2013 barjac <barjac> 1.0.8-7.mga3
+ Revision: 409667
- rebuild for boost-1.53

* Sun Jan 13 2013 umeabot <umeabot> 1.0.8-6.mga3
+ Revision: 362041
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.0.8-5.mga3
+ Revision: 332957
- rebuild for new boost

* Sun Dec 02 2012 fwang <fwang> 1.0.8-4.mga3
+ Revision: 325021
- rebuild for  new openexr

* Sun Oct 07 2012 fwang <fwang> 1.0.8-3.mga3
+ Revision: 303247
- rebuild for new openjpeg

* Tue Aug 21 2012 fwang <fwang> 1.0.8-2.mga3
+ Revision: 282870
- rebuild for new glew

* Tue Jul 31 2012 fwang <fwang> 1.0.8-1.mga3
+ Revision: 276474
- new version 1.0.8
- rebuild for new glew

* Tue May 29 2012 fwang <fwang> 1.0.4-2.mga3
+ Revision: 249531
- rebuild for new boost

* Fri May 25 2012 fwang <fwang> 1.0.4-1.mga3
+ Revision: 236018
- fix upgrade from previous name
- br jpeg
- imported package openimageio

